@@ -39,10 +39,11 @@ const (
 
 var (
 	// NOTE: Ensure that there is an entry for each supported version in the following tables.
-	supportedVersions = []string{"1.25", "1.24", "1.23", "1.22"}
+	supportedVersions = []string{"1.26", "1.25", "1.24", "1.23", "1.22"}
 
 	// Reference: https://docs.aws.amazon.com/eks/latest/userguide/managing-coredns.html
 	coreDNSVersionLookupTable = map[string]string{
+		"1.26": "1.9.3-eksbuild",
 		"1.25": "1.9.3-eksbuild",
 		"1.24": "1.8.7-eksbuild",
 		"1.23": "1.8.7-eksbuild",
@@ -51,6 +52,7 @@ var (
 
 	// Reference: https://docs.aws.amazon.com/eks/latest/userguide/managing-kube-proxy.html#updating-kube-proxy-add-on
 	kubeProxyVersionLookupTable = map[string]string{
+		"1.26": "1.26.2-minimal-eksbuild",
 		"1.25": "1.25.6-minimal-eksbuild",
 		"1.24": "1.24.7-minimal-eksbuild",
 		"1.23": "1.23.8-minimal-eksbuild",
@@ -59,6 +61,7 @@ var (
 
 	// Reference: https://docs.aws.amazon.com/eks/latest/userguide/managing-vpc-cni.html
 	amazonVPCCNIVersionLookupTable = map[string]string{
+		"1.26": "1.12.6",
 		"1.25": "1.12.2",
 		"1.24": "1.11.4",
 		"1.23": "1.11.4",
